@@ -164,13 +164,8 @@ def __get_default_backup_filename(config):
 @click.argument("filename")
 @pass_config
 def get_dump_type(config, filename):
-    BACKUPDIR = Path(config.dumps_path)
-    if not filename:
-        filename = _inquirer_dump_file(config, "", config.dbname)
-    if filename:
-        dump_file = BACKUPDIR / filename
-        dump_type = _add_cronjob_scripts(config)["postgres"].__get_dump_type(dump_file)
-        click.echo(dump_type)
+    dump_type = _add_cronjob_scripts(config)["postgres"].__get_dump_type(filename)
+    click.echo(dump_type)
 
 
 @restore.command(name="list")
@@ -248,7 +243,7 @@ def _restore_wodoo_bin(ctx, config, filepath, verify):
 @click.option('--latest', default=False, is_flag=True, help="Restore latest dump")
 @click.option('--no-dev-scripts', default=False, is_flag=True)
 @click.option('--no-remove-webassets', default=False, is_flag=True)
-@click.option('--verify', default=False, is_flag=True)
+@click.option('--verify', default=False, is_flag=True, help="Wodoo-bin: checks postgres version")
 @pass_config
 @click.pass_context
 def restore_db(ctx, config, filename, latest, no_dev_scripts, no_remove_webassets, verify):
